@@ -49,7 +49,6 @@ typedef struct {
 	EmpathyTpGroup        *group;
 	McAccount             *account;
 	TpChannel             *channel;
-	gchar                 *id;
 	gboolean               listing_pending_messages;
 	/* Queue of messages not signalled yet */
 	GQueue                *messages_queue;
@@ -92,6 +91,8 @@ G_DEFINE_TYPE_WITH_CODE (EmpathyTpChat, empathy_tp_chat, G_TYPE_OBJECT,
 			 G_IMPLEMENT_INTERFACE (EMPATHY_TYPE_CONTACT_LIST,
 						tp_chat_iface_init));
 
+static void acknowledge_messages (EmpathyTpChat *chat, GArray *ids);
+
 static void
 tp_chat_invalidated_cb (TpProxy       *proxy,
 			guint          domain,
@@ -418,8 +419,9 @@ tp_chat_received_cb (TpChannel   *channel,
 		     guint        message_flags,
 		     const gchar *message_body,
 		     gpointer     user_data,
-		     GObject     *chat)
+		     GObject     *chat_)
 {
+	EmpathyTpChat *chat = EMPATHY_TP_CHAT (chat_);
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
 	EmpathyMessage    *message;
 
@@ -432,14 +434,28 @@ tp_chat_received_cb (TpChannel   *channel,
  
  	DEBUG ("Message received: %s", message_body);
 
-	message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
+	if (message_flags & TP_CHANNEL_TEXT_MESSAGE_FLAG_NON_TEXT_CONTENT &&
+	    !tp_strdiff (message_body, "")) {
+		GArray *ids;
+
+		DEBUG ("Empty message with NonTextContent, ignoring and acking.");
+
+		ids = g_array_sized_new (FALSE, FALSE, sizeof (guint), 1);
+		g_array_append_val (ids, message_id);
+		acknowledge_messages (chat, ids);
+		g_array_free (ids, TRUE);
+
+		return;
+	}
+
+	message = tp_chat_build_message (chat,
 					 message_id,
 					 message_type,
 					 timestamp,
 					 from_handle,
 					 message_body);
 
-	tp_chat_emit_or_queue_message (EMPATHY_TP_CHAT (chat), message);
+	tp_chat_emit_or_queue_message (chat, message);
 	g_object_unref (message);
 }
 
@@ -449,8 +465,9 @@ tp_chat_sent_cb (TpChannel   *channel,
 		 guint        message_type,
 		 const gchar *message_body,
 		 gpointer     user_data,
-		 GObject     *chat)
+		 GObject     *chat_)
 {
+	EmpathyTpChat *chat = EMPATHY_TP_CHAT (chat_);
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
 	EmpathyMessage *message;
 
@@ -459,14 +476,14 @@ tp_chat_sent_cb (TpChannel   *channel,
 
 	DEBUG ("Message sent: %s", message_body);
 
-	message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
+	message = tp_chat_build_message (chat,
 					 0,
 					 message_type,
 					 timestamp,
 					 0,
 					 message_body);
 
-	tp_chat_emit_or_queue_message (EMPATHY_TP_CHAT (chat), message);
+	tp_chat_emit_or_queue_message (chat, message);
 	g_object_unref (message);
 }
 
@@ -542,10 +559,12 @@ tp_chat_list_pending_messages_cb (TpChannel       *channel,
 				  const GPtrArray *messages_list,
 				  const GError    *error,
 				  gpointer         user_data,
-				  GObject         *chat)
+				  GObject         *chat_)
 {
+	EmpathyTpChat     *chat = EMPATHY_TP_CHAT (chat_);
 	EmpathyTpChatPriv *priv = GET_PRIV (chat);
 	guint              i;
+	GArray            *empty_non_text_content_ids = NULL;
 
 	priv->listing_pending_messages = FALSE;
 
@@ -578,16 +597,33 @@ tp_chat_list_pending_messages_cb (TpChannel       *channel,
 
 		DEBUG ("Message pending: %s", message_body);
 
-		message = tp_chat_build_message (EMPATHY_TP_CHAT (chat),
+		if (message_flags & TP_CHANNEL_TEXT_MESSAGE_FLAG_NON_TEXT_CONTENT &&
+		    !tp_strdiff (message_body, "")) {
+			DEBUG ("Empty message with NonTextContent, ignoring and acking.");
+
+			if (empty_non_text_content_ids == NULL) {
+				empty_non_text_content_ids = g_array_new (FALSE, FALSE, sizeof (guint));
+			}
+
+			g_array_append_val (empty_non_text_content_ids, message_id);
+			continue;
+		}
+
+		message = tp_chat_build_message (chat,
 						 message_id,
 						 message_type,
 						 timestamp,
 						 from_handle,
 						 message_body);
 
-		tp_chat_emit_or_queue_message (EMPATHY_TP_CHAT (chat), message);
+		tp_chat_emit_or_queue_message (chat, message);
 		g_object_unref (message);
 	}
+
+	if (empty_non_text_content_ids != NULL) {
+		acknowledge_messages (chat, empty_non_text_content_ids);
+		g_array_free (empty_non_text_content_ids, TRUE);
+	}
 }
 
 static void
@@ -806,20 +842,6 @@ tp_chat_channel_ready_cb (EmpathyTpChat *chat)
 		      "handle_type", &handle_type,
 		      NULL);
 
-	if (handle_type != TP_HANDLE_TYPE_NONE && handle != 0) {
-		GArray *handles;
-		gchar **names;
-
-		handles = g_array_new (FALSE, FALSE, sizeof (guint));
-		g_array_append_val (handles, handle);
-		tp_cli_connection_run_inspect_handles (connection, -1,
-						       handle_type, handles,
-						       &names, NULL, NULL);
-		priv->id = *names;
-		g_array_free (handles, TRUE);
-		g_free (names);
-	}
-
 	if (handle_type == TP_HANDLE_TYPE_CONTACT && handle != 0) {
 		priv->remote_contact = empathy_contact_factory_get_from_handle (priv->factory,
 										priv->account,
@@ -979,8 +1001,6 @@ tp_chat_finalize (GObject *object)
 		g_ptr_array_free (priv->properties, TRUE);
 	}
 
-
-	g_free (priv->id);
 	g_queue_free (priv->messages_queue);
 	g_queue_free (priv->pending_messages_queue);
 
@@ -1205,7 +1225,7 @@ empathy_tp_chat_get_id (EmpathyTpChat *chat)
 	g_return_val_if_fail (EMPATHY_IS_TP_CHAT (chat), NULL);
 	g_return_val_if_fail (priv->ready, NULL);
 
-	return priv->id;
+	return tp_channel_get_identifier (priv->channel);
 }
 
 EmpathyContact *
